@@ -1,10 +1,13 @@
 <?php
 /***                                                                        ***\
-    settings.php                            Last Updated: 2003.08.22 (xris)
+    settings.php                            Last Updated: 2005.01.23 (xris)
 
     main configuration index
 \***                                                                        ***/
 
+// Which section are we in?
+    define('section', 'settings');
+
 // Initialize the script, database, etc.
     require_once "includes/init.php";
 
